Learn R Programming

angstroms (version 0.0.1)

croproms: Crop a ROMS layer

Description

Crop a ROMS data layer from romsdata with a raster extent.

Usage

croproms(x, ext, ...)

Arguments

x
ROMS xy- coordinates, see romscoords
ext
raster::extent in the coordinate system of x
...
ignored

Details

The spatial crop is performed in the coordinate space of roms data.

Examples

Run this code
## notice that extent is in long-lat, but ice_local is in the grid
## space of ice_coords
ice_local <- croproms(ice_coords, extent(100, 120, -75, -60))
plot(ice_coords[[2]], col = grey(seq(0, 1, length  = 20)))
plot(crop(ice_fake, ice_local), add = TRUE)

Run the code above in your browser using DataLab